@@ -213,7 +213,7 @@ tkgrid(tklabel(tt,text="Label    "),canvas2,ChangeColor.button2)
    tkgrid(tklabel(tt,text="    "))
 tkgrid(tklabel(tt,text="Axis    "),canvas3,ChangeColor.button3)
    tkgrid(tklabel(tt,text="    "))
-tkgrid(tklabel(tt,text="Legent    "),canvas4,ChangeColor.button4)
+tkgrid(tklabel(tt,text="Legend    "),canvas4,ChangeColor.button4)
    tkgrid(tklabel(tt,text="    "))
 tkgrid(tklabel(tt,text="Title    "),canvas5,ChangeColor.button5)
    tkgrid(tklabel(tt,text="    "))
@@ -238,7 +238,7 @@ tkgrid(OK.but,Cancel.but)
   textEntryWidget4 <- tkentry(dlg,width=paste(entryWidth),textvariable=textEntryVarTcl4)
 
   tkgrid(tklabel(dlg,text="       "))
-  tkgrid(tklabel(dlg,text="Change the Legent"),sticky="w")
+  tkgrid(tklabel(dlg,text="Change the Legend"),sticky="w")
    tkgrid(tklabel(dlg,text="       "))
   tkgrid(tklabel(dlg,text=question),textEntryWidget,sticky="e")
   tkgrid(tklabel(dlg,text=question2),textEntryWidget2,sticky="e")
@@ -423,7 +423,7 @@ tkgrid(tklabel(dlg,text="Text Size"),sticky="w")
 tkgrid(tklabel(dlg,text="       "))
 tkgrid(tklabel(dlg,text="Labels : "),SliderValueLabel1,slider1)
 tkgrid(tklabel(dlg,text="Axis : "),SliderValueLabel2,slider2)
-tkgrid(tklabel(dlg,text="Legent : "),SliderValueLabel3,slider3)
+tkgrid(tklabel(dlg,text="Legend : "),SliderValueLabel3,slider3)
 tkgrid(tklabel(dlg,text="Title : "),SliderValueLabel4,slider4)
 tkgrid(tklabel(dlg,text="Subtitle : "),SliderValueLabel5,slider5)
 tkgrid(tklabel(dlg,text="       "))
@@ -492,10 +492,10 @@ change.espectrum()
         command=change.color.bakground)
   legent <- tkmenu(Menu,borderwidth=40,tearoff=FALSE)
   tkadd(legent, "command", label="Text",
-        command=function() modalDialog4("Legent   ","Xlab   ","Ylab   ","Main Title   ","Subtitle", xlab,ylab,main,subt))
+        command=function() modalDialog4("Legend   ","Xlab   ","Ylab   ","Main Title   ","Subtitle", xlab,ylab,main,subt))
   tkadd(legent, "command", label="Size",
         command=function() Text.size())
-  tkadd(Menu, "cascade", label="Legent",menu=legent)
+  tkadd(Menu, "cascade", label="Legend",menu=legent)
 #  tkadd(Menu, "command", label="Spectrum",
 #        command=function() c.spectrum())
   tkadd(Menu, "command", label="Zoom",
